@@ -1,6 +1,4 @@
-from __future__ import absolute_import, unicode_literals
-
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 from oauthlib.oauth1 import RequestValidator
 from oauthlib.oauth1.rfc5849 import errors
